searchData={"items":[{"type":"module","title":"Lua","doc":"Lua is an ergonomic interface to [Luerl](https://github.com/rvirding/luerl), aiming to be the best way to use Luerl from Elixir.","ref":"Lua.html"},{"type":"module","title":"Features - Lua","doc":"* Ergonomic API for Elixir <> Lua FFI\n* Improved error messages\n* Deep-setting variables and state\n* Excellent documentation and guides for working with Luerl","ref":"Lua.html#module-features"},{"type":"module","title":"Executing Lua - Lua","doc":"Lua can be run using the `eval!/2` function\n\n``` elixir\n    iex> {[4], _} =\n    ...>   Lua.eval!(\"\"\"\n    ...>   return 2 + 2\n    ...>   \"\"\")\n\n```","ref":"Lua.html#module-executing-lua"},{"type":"module","title":"Exposing Elixir functions to Lua - Lua","doc":"`Lua` provides the `deflua` macro for exposing Elixir functions to Lua\n\n``` elixir\ndefmodule MyAPI do\n  use Lua.API\n      \n  deflua double(v), do: 2 * v\nend\n    \nlua = Lua.new() |> Lua.load_api(MyAPI)\n\n{[10], _} =\n  Lua.eval!(lua, \"\"\"\n  return double(5)\n  \"\"\")\n\n```","ref":"Lua.html#module-exposing-elixir-functions-to-lua"},{"type":"module","title":"Credits - Lua","doc":"Lua piggy-backs off of Robert Virding's Luerl project, which implements an Lua lexer, parser, and full-blown lua virtual machine that runs inside the BEAM.","ref":"Lua.html#module-credits"},{"type":"function","title":"Lua.eval!/2","doc":"Evalutes the script or chunk, returning the result and\ndiscarding side effects in the state","ref":"Lua.html#eval!/2"},{"type":"function","title":"Lua.get!/2","doc":"Gets a table value in Lua\n\n    iex> state = Lua.set!(Lua.new(), [:hello], \"world\")\n    iex> Lua.get!(state, [:hello])\n    \"world\"\n\nWhen a value doesn't exist, it returns nil\n\n    iex> Lua.get!(Lua.new(), [:nope])\n    nil\n\nIt can also get nested values\n\n    iex> state = Lua.set!(Lua.new(), [:a, :b, :c], \"nested\")\n    iex> Lua.get!(state, [:a, :b, :c])\n    \"nested\"","ref":"Lua.html#get!/2"},{"type":"function","title":"Lua.load_api/3","doc":"Inject functions written with the `deflua` macro into the Lua\nruntime","ref":"Lua.html#load_api/3"},{"type":"function","title":"Lua.load_lua_file!/2","doc":"","ref":"Lua.html#load_lua_file!/2"},{"type":"function","title":"Lua.new/1","doc":"Initializes a Lua VM sandbox. All library functions are stubbed out,\nso no access to the filesystem or the execution environment is exposed.","ref":"Lua.html#new/1"},{"type":"function","title":"Options - Lua.new/1","doc":"* `:sandboxed` - list of paths to be sandboxed, e.g. `sandboxed: [[:require], [:os, :exit]]`","ref":"Lua.html#new/1-options"},{"type":"function","title":"Lua.sandbox/2","doc":"Sandboxes the given path, swapping out the implementation with\na function that raises when called\n\n    iex> lua = Lua.new(sandboxed: [])\n    iex> Lua.sandbox(lua, [:os, :exit])","ref":"Lua.html#sandbox/2"},{"type":"function","title":"Lua.set!/3","doc":"Sets a table value in Lua. Nested keys will create\nintermediate tables\n\n    iex> Lua.set!(Lua.new(), [:hello], \"World\")\n\nIt can also set nested values\n\n    iex> Lua.set!(Lua.new(), [:a, :b, :c], [])\n\nThese table values are availble in lua scripts\n\n    iex> lua = Lua.set!(Lua.new(), [:a, :b, :c], \"nested!\")\n    iex> {result, _} = Lua.eval!(lua, \"return a.b.c\")\n    iex> result\n    [\"nested!\"]","ref":"Lua.html#set!/3"},{"type":"function","title":"Lua.set_lua_paths/2","doc":"Sets the path patterns that Lua will look in when requiring Lua scripts.","ref":"Lua.html#set_lua_paths/2"},{"type":"behaviour","title":"Lua.API","doc":"Defines the Behaviour for defining a Lua API\n\nTo create a module that exports functions to the global scope\n\n    defmodule MyAPI do\n      use Lua.API\n\n      # Can be called via `print(\"hi\")` in lua\n      deflua print(msg), do: IO.puts msg\n    end\n\nOptionally, you can provide a scope\n\n    defmodule SpecificAPI do\n      use Lua.API, scope: \"namespace.domain\"\n\n      # Can be called via `namespace.domain.foo(5)` in lua\n      deflua foo(v), do: v\n    end\n\nYou can access Lua state\n\n    defmodule State do\n      use Lua.API\n\n      deflua bar(name), state do\n        # Pull's the value of `number` out of state\n        val = Lua.get!(state, [:number])\n\n        2 * val\n      end\n    end\n\nRegular functions are not exported\n\n    defmodule SpecificAPI do\n      use Lua.API\n\n      # Won't be exposed\n      def baz(v), do: v\n    end","ref":"Lua.API.html"},{"type":"macro","title":"Lua.API.deflua/2","doc":"","ref":"Lua.API.html#deflua/2"},{"type":"macro","title":"Lua.API.deflua/3","doc":"Define a function that can be exposed in Lua","ref":"Lua.API.html#deflua/3"},{"type":"macro","title":"Lua.API.runtime_exception!/1","doc":"Raises a runtime exception inside an API function, displaying contextual\ninformation about where the exception was raised.","ref":"Lua.API.html#runtime_exception!/1"},{"type":"callback","title":"Lua.API.scope/0","doc":"","ref":"Lua.API.html#c:scope/0"},{"type":"exception","title":"Lua.CompilerException","doc":"","ref":"Lua.CompilerException.html"},{"type":"exception","title":"Lua.RuntimeException","doc":"","ref":"Lua.RuntimeException.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}